:class:`MotorCursor`
========================

.. currentmodule:: motor

.. autoclass:: MotorCursor
  :members:

  .. describe:: c[index]

     See :meth:`__getitem__`.

  .. automethod:: __getitem__
